LiveActivityState class final
Snapshot of an active Live Activity.
Constructors
-
LiveActivityState({required String activityId, required String attributesType, required Map<
String, FlowWidgetValue> data, required DateTime startedAt, DateTime? staleDate}) -
Creates a Live Activity state.
const
-
LiveActivityState.fromWire(Map<
Object?, Object?> wire) -
Wire decoding.
factory
Properties
- activityId → String
-
Platform activity identifier.
final
- attributesType → String
-
ActivityAttributes type name.
final
-
data
→ Map<
String, FlowWidgetValue> -
Current content-state data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- staleDate → DateTime?
-
Stale date, if set.
final
- startedAt → DateTime
-
Start timestamp.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited